declare const visuallyHidden = "\n\tposition: absolute;\n\topacity: 0;\n\theight: 0;\n\twidth: 0;\n\ttop: 0;\n\tleft: 0;\n";
declare const focusHalo: string;
declare const descriptionId: (id: string) => string;
declare const generateSourceId: () => string;

declare const transitions: {
    short: string;
    medium: string;
    long: string;
};

declare type Breakpoint = 'mobile' | 'mobileMedium' | 'mobileLandscape' | 'phablet' | 'tablet' | 'desktop' | 'leftCol' | 'wide';
declare const breakpoints: {
    mobile: number;
    mobileMedium: number;
    mobileLandscape: number;
    phablet: number;
    tablet: number;
    desktop: number;
    leftCol: number;
    wide: number;
};

declare type BreakpointMap = {
    [key in Breakpoint]: string;
};
declare const from: BreakpointMap;
declare const until: BreakpointMap;
declare const between: {
    mobile: {
        and: {
            mobileMedium: string;
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileMedium: {
        and: {
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileLandscape: {
        and: {
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    phablet: {
        and: {
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    tablet: {
        and: {
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    desktop: {
        and: {
            leftCol: string;
            wide: string;
        };
    };
    leftCol: {
        and: {
            wide: string;
        };
    };
};

declare const brand: {
    100: string;
    300: string;
    400: string;
    500: string;
    600: string;
    800: string;
};
declare const brandAlt: {
    200: string;
    300: string;
    400: string;
};
declare const neutral: {
    0: string;
    7: string;
    10: string;
    20: string;
    46: string;
    60: string;
    86: string;
    93: string;
    97: string;
    100: string;
};
declare const error: {
    400: string;
    500: string;
};
declare const success: {
    400: string;
    500: string;
};
declare const news: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    550: string;
    600: string;
    800: string;
};
declare const opinion: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    550: string;
    600: string;
    800: string;
};
declare const sport: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    600: string;
    800: string;
};
declare const culture: {
    50: string;
    100: string;
    200: string;
    300: string;
    350: string;
    400: string;
    500: string;
    600: string;
    700: string;
    800: string;
};
declare const lifestyle: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    600: string;
    800: string;
};
declare const labs: {
    200: string;
    300: string;
    400: string;
};
declare const specialReport: {
    100: string;
    200: string;
    300: string;
    400: string;
    450: string;
    500: string;
    700: string;
    800: string;
};
declare const focus: {
    400: string;
};
declare const background: {
    primary: string;
    secondary: string;
    inverse: string;
    ctaPrimary: string;
    ctaPrimaryHover: string;
    ctaSecondary: string;
    ctaSecondaryHover: string;
    ctaTertiaryHover: string;
    input: string;
    inputChecked: string;
};
declare const brandBackground: {
    primary: string;
    inputChecked: string;
    ctaPrimary: string;
    ctaPrimaryHover: string;
    ctaSecondary: string;
    ctaSecondaryHover: string;
    ctaTertiaryHover: string;
};
declare const brandAltBackground: {
    primary: string;
    ctaPrimary: string;
    ctaPrimaryHover: string;
    ctaSecondary: string;
    ctaSecondaryHover: string;
    ctaTertiaryHover: string;
};
declare const border: {
    primary: string;
    secondary: string;
    success: string;
    error: string;
    ctaTertiary: string;
    input: string;
    inputChecked: string;
    inputHover: string;
    inputActive: string;
    focusHalo: string;
};
declare const brandBorder: {
    primary: string;
    secondary: string;
    success: string;
    error: string;
    ctaTertiary: string;
    input: string;
    inputChecked: string;
    inputHover: string;
};
declare const brandAltBorder: {
    ctaTertiary: string;
};
declare const line: {
    primary: string;
};
declare const brandLine: {
    primary: string;
};
declare const brandAltLine: {
    primary: string;
};
declare const text: {
    primary: string;
    supporting: string;
    success: string;
    error: string;
    ctaPrimary: string;
    ctaSecondary: string;
    ctaTertiary: string;
    anchorPrimary: string;
    anchorSecondary: string;
    userInput: string;
    inputLabel: string;
    inputLabelSupporting: string;
    inputChecked: string;
    inputHover: string;
    groupLabel: string;
    groupLabelSupporting: string;
    newsInverse: string;
};
declare const brandText: {
    primary: string;
    supporting: string;
    success: string;
    error: string;
    ctaPrimary: string;
    ctaSecondary: string;
    ctaTertiary: string;
    anchorPrimary: string;
    anchorPrimaryHover: string;
    userInput: string;
    inputLabel: string;
    inputLabelSupporting: string;
};
declare const brandAltText: {
    primary: string;
    supporting: string;
    ctaPrimary: string;
    ctaSecondary: string;
    ctaTertiary: string;
    anchorPrimary: string;
};

declare const size: {
    xsmall: number;
    small: number;
    medium: number;
};
declare const iconSize: {
    xsmall: number;
    small: number;
    medium: number;
};
declare const height: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputMedium: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
declare const remHeight: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputMedium: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
declare const width: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
declare const remWidth: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};

declare const space: {
    1: number;
    2: number;
    3: number;
    4: number;
    5: number;
    6: number;
    9: number;
    12: number;
    24: number;
};
declare const remSpace: {
    [K in keyof typeof space]: string;
};

declare type ScaleUnit = 'rem' | 'px';
declare type Category = 'titlepiece' | 'headline' | 'body' | 'textSans';
declare type LineHeight = 'tight' | 'regular' | 'loose';
declare type FontWeight = 'light' | 'regular' | 'medium' | 'bold';
declare type FontStyle = 'normal' | 'italic';
declare type FontWeightDefinition = {
    hasItalic: boolean;
};
declare type Option<A> = A | null;
declare type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: string | number;
    fontWeight?: number;
    fontStyle?: string;
};
declare type TypographySizes = {
    [key in string]: number;
};
interface TitlepieceSizes extends TypographySizes {
    small: number;
    medium: number;
    large: number;
}
interface HeadlineSizes extends TypographySizes {
    xxxsmall: number;
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
}
interface BodySizes extends TypographySizes {
    small: number;
    medium: number;
}
interface TextSansSizes extends TypographySizes {
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
    xxxlarge: number;
}
declare type Fs = (category: Category) => (level: string, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
declare type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
declare type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}

declare const titlepieceSizes: TitlepieceSizes;
declare const headlineSizes: HeadlineSizes;
declare const bodySizes: BodySizes;
declare const textSansSizes: TextSansSizes;
declare const remTitlepieceSizes: TitlepieceSizes;
declare const remHeadlineSizes: HeadlineSizes;
declare const remBodySizes: BodySizes;
declare const remTextSansSizes: TextSansSizes;
declare const fontMapping: {
    [cat in Category]: string;
};
declare const lineHeightMapping: {
    [lineHight in LineHeight]: number;
};
declare const fontWeightMapping: {
    [fontWeight in FontWeight]: number;
};

declare type TypographyApi<Sizes> = {
    [key in keyof Sizes]: FontScaleFunctionStr;
};
declare const titlepiece$1: TypographyApi<TitlepieceSizes>;
declare const headline$1: TypographyApi<HeadlineSizes>;
declare const body$1: TypographyApi<BodySizes>;
declare const textSans$1: TypographyApi<TextSansSizes>;

declare type TitlepieceFunctions = {
    [key in keyof TitlepieceSizes]: FontScaleFunction;
};
declare const titlepiece: TitlepieceFunctions;
declare type HeadlineFunctions = {
    [key in keyof HeadlineSizes]: FontScaleFunction;
};
declare const headline: HeadlineFunctions;
declare type BodyFunctions = {
    [key in keyof BodySizes]: FontScaleFunction;
};
declare const body: BodyFunctions;
declare type TextSansFunctions = {
    [key in keyof TextSansSizes]: FontScaleFunction;
};
declare const textSans: TextSansFunctions;

declare const appearance = "(appearance: none) or (-webkit-appearance: none) or (-moz-appearance: none)";

declare const FocusStyleManager: {
    alwaysShowFocus: () => void;
    isActive: () => boolean;
    onlyShowFocusOnTabs: () => void;
};

declare const rootPixelFontSize = 16;
declare const pxToRem: (px: number) => number;

declare const resets: {
    legend: string;
    fieldset: string;
    input: string;
    defaults: string;
    resetCSS: string;
};

export { BodySizes, Breakpoint, Category, FocusStyleManager, FontScaleArgs, FontScaleFunction, FontScaleFunctionStr, FontStyle, FontWeight, FontWeightDefinition, Fs, HeadlineSizes, LineHeight, Option, ScaleUnit, TextSansSizes, TitlepieceSizes, TypographySizes, TypographyStyles, appearance, background, between, body$1 as body, body as bodyObjectStyles, bodySizes, border, brand, brandAlt, brandAltBackground, brandAltBorder, brandAltLine, brandAltText, brandBackground, brandBorder, brandLine, brandText, breakpoints, culture, descriptionId, error, focus, focusHalo, fontWeightMapping as fontWeights, fontMapping as fonts, from, generateSourceId, headline$1 as headline, headline as headlineObjectStyles, headlineSizes, height, iconSize, labs, lifestyle, line, lineHeightMapping as lineHeights, neutral, news, opinion, pxToRem, remBodySizes, remHeadlineSizes, remHeight, remSpace, remTextSansSizes, remTitlepieceSizes, remWidth, resets, rootPixelFontSize, size, space, specialReport, sport, success, text, textSans$1 as textSans, textSans as textSansObjectStyles, textSansSizes, titlepiece$1 as titlepiece, titlepiece as titlepieceObjectStyles, titlepieceSizes, transitions, until, visuallyHidden, width };
